@@ -19,7 +19,7 @@ our %EXPORT_TAGS = (all => \@EXPORT_OK);
 use App::Memcached::CLI;
 use App::Memcached::CLI::Constants ':all';
 
-use version; our $VERSION = 'v0.2.0';
+use version; our $VERSION = 'v0.2.1';
 
 sub looks_like_addr {
     my $string = shift;
@@ -63,15 +63,20 @@ __END__
 
 =head1 NAME
 
-App::Memcached::CLI::Util - It's new $module
+App::Memcached::CLI::Util - Utility functions for memcached-cli
 
 =head1 SYNOPSIS
 
-    use App::Memcached::CLI::Util;
+    use App::Memcached::CLI::Util ':all';
+    if (looks_like_addr($given)) {
+        ...
+    }
+    my $addr = is_unixsocket($given) ? $given : create_addr($hostname);
+    debug "foo";
 
 =head1 DESCRIPTION
 
-App::Memcached::CLI::Util is ...
+This module provides utility functions for other modules.
 
 =head1 LICENSE
 
